
# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2010 Tiny SPRL (<http://tiny.be>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from openerp.osv import fields, osv
from openerp.tools.translate import _
from datetime import datetime, timedelta

class pos_customer(osv.osv_memory):
	_name = "pos.customer"
	
	def default_get(self, cr, uid, fields, context=None):
		if context is None:
			context={}
		res = super(pos_customer, self).default_get(cr, uid, fields, context)
		if context.get('modify') and context.get('default_partner_id'):
			default_values = self.pool.get('res.partner').read(cr,uid,context['default_partner_id'],['name','street','street2','zip','city','state_id','country_id','phone','mobile','email','image_medium'])
			default_values.pop('id')
			state_id = default_values.pop('state_id')
			country_id = default_values.pop('country_id')
			default_values['state_id'] = state_id and state_id[0] or False
			default_values['country_id'] = country_id and country_id[0] or False
			res.update(default_values)
		return res

	def get_last_created_customer_data(self,cr,uid,context=None):
		if context is None:
			context = {}
		cr.execute('select "partner_id" from "pos_customer" order by "id" desc limit 1')
		last_created_partner_id = cr.fetchone()
		customer_data = self.pool.get('res.partner').read(cr,uid,last_created_partner_id[0],['name','contact_address','email','phone','mobile'])
		return customer_data

	def create_customer(self,cr,uid,ids,context=None):
		if context is None:
			context = {}
		create_data = self.read(cr,uid,ids[0])
		partner_id = create_data.pop('partner_id')
		country_id = create_data.pop('country_id')
		state_id = create_data.pop('state_id')
		create_data['country_id'] = country_id and country_id[0] or False
		create_data['state_id'] = state_id and state_id[0] or False
		create_data.pop('id')
		partner_id = self.pool.get('res.partner').create(cr,uid,create_data,context)
		self.write(cr,uid,ids[0],{'partner_id':partner_id})
		return {'type': 'ir.actions.act_window_close'}

	def modify_customer(self,cr,uid,ids,context=None):
		if context is None:
			context = {}
		modify_data = self.read(cr,uid,ids[0])
		partner_id = modify_data.pop('partner_id')
		country_id = modify_data.pop('country_id')
		state_id = modify_data.pop('state_id')
		modify_data['country_id'] = country_id and country_id[0] or False
		modify_data['state_id'] = state_id and state_id[0] or False
		modify_data.pop('id')
		modify_data.pop('customer')
		self.pool.get('res.partner').write(cr,uid,partner_id[0],modify_data,context)
		return {'type': 'ir.actions.act_window_close'}

	def onchange_state(self, cr, uid, ids, state_id, context=None):
		if state_id:
			country_id = self.pool.get('res.country.state').browse(cr, uid, state_id, context).country_id.id
			return {'value':{'country_id':country_id}}
		return {}	

	_columns={
			'name': fields.char('Name', size=128, required=True, select=True),
			'customer': fields.boolean('Customer', help="Check this box if this contact is a customer."),
			'phone': fields.char('Phone', size=64),
			'mobile': fields.char('Mobile', size=64),
			'email': fields.char('Email', size=240),
	        'street': fields.char('Street', size=128),
	        'street2': fields.char('Street2', size=128),
	        'zip': fields.char('Zip', change_default=True, size=24),
	        'city': fields.char('City', size=128),
	        'state_id': fields.many2one("res.country.state", 'State'),
	        'country_id': fields.many2one('res.country', 'Country'),
	        'partner_id': fields.many2one('res.partner', 'Original Partner'),
	        'image_medium': fields.binary("Image"),
	         }
	_defaults = {
        'customer': 1,
    }
pos_customer()
